VIAudioDeviceChanged typedef
VIAudioDeviceChanged =
void Function(VIAudioDeviceManager audioManager, VIAudioDevice device)
Signature for callbacks reporting that the active audio device or audio device that is used for a further call is changed.
If the event is triggered during a call, device is the audio device that
is currently used.
If the event is triggered when there is no call, device is the audio device
that is used for the next call.
audioManager - VIAudioDeviceManager instance initiated the event
device - Audio device to be used
Implementation
typedef void VIAudioDeviceChanged(
VIAudioDeviceManager audioManager,
VIAudioDevice device,
);