VICall class

Represents a call.

Properties

callId String
Call ID.
no setter
callKitUUID String?
CallKit UUID that may be used to match an incoming call with a push notification received before.
getter/setter pair
endpoints List<VIEndpoint>
Endpoints associated with the call.
no setter
hashCode int
The hash code for this object.
no setterinherited
localVideoStream VIVideoStream?
Active local video stream.
no setter
onCallAudioStarted VICallAudioStarted?
Triggered when the endpoint answered the call.
getter/setter pair
onCallConnected VICallConnected?
Triggered when the call is connected.
getter/setter pair
onCallDisconnected VICallDisconnected?
Triggered when the call is disconnected.
getter/setter pair
onCallFailed VICallFailed?
Triggered when the call is failed.
getter/setter pair
onCallReconnected VICallReconnected?
Triggered when the call is reconnected.
getter/setter pair
onCallReconnecting VICallReconnecting?
Triggered when the call is currently reconnecting.
getter/setter pair
onCallRinging VICallRinging?
Triggered when a progress tone is received from the endpoint.
getter/setter pair
onEndpointAdded VIEndpointAdded?
Triggered when a new endpoint is added to the call.
getter/setter pair
onICECompleted VIICECompleted?
Triggered when the ICE connection is completed.
getter/setter pair
onICETimeout VIICETimeout?
Callback for getting notified about failure to connect peers.
getter/setter pair
onLocalVideoStreamAdded VILocalVideoStreamAdded?
Triggered when the local video is added to the call.
getter/setter pair
onLocalVideoStreamRemoved VILocalVideoStreamRemoved?
Triggered when the local video is removed from the call.
getter/setter pair
onMessageReceived VIMessageReceived?
Triggered when a message is received.
getter/setter pair
onSIPInfoReceived VISIPInfoReceived?
Triggered when an INFO message in received.
getter/setter pair
qualityIssuesStream Stream<VIQualityIssue>
Stream to monitor issues that affect call quality.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

answer({VICallSettings? settings}) Future<void>
Answers the incoming call.
currentQualityIssues() Future<Map<VIQualityIssueType, VIQualityIssueLevel>>
Returns current status for all quality issues.
decline([Map<String, String>? headers]) Future<void>
Declines the incoming call.
getCallDuration() Future<int?>
Returns the call duration in milliseconds.
hangup([Map<String, String>? headers]) Future<void>
Disconnects the call.
hold(bool enable) Future<void>
Puts the call on/off hold.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
receiveVideo() Future<void>
Starts receiving video if video receive has been disabled before.
reject([Map<String, String>? headers]) Future<void>
Rejects the incoming call.
sendAudio(bool enable) Future<void>
Enables or disables audio transfer from microphone into the call.
sendInfo(String mimeType, String body, Map<String, String>? headers) Future<void>
Sends an INFO message within the call.
sendMessage(String message) Future<void>
Sends a message within the call.
sendTone(String key) Future<void>
Sends DTMFs in the call.
sendVideo(bool enable) Future<void>
Starts or stops sending video for the call.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited