VICallDisconnected typedef
VICallDisconnected =
void Function(VICall call, Map<String, String> ? headers, bool answeredElsewhere)
Signature for callbacks reporting that the call is disconnected.
Used in VICall.
call - VICall instance initiated the event
headers - Optional SIP headers
answeredElsewhere - Whether the call has been answered on another device
Implementation
typedef void VICallDisconnected(
VICall call,
Map<String, String>? headers,
bool answeredElsewhere,
);