VIClient class

Interface that may be used to connect, login to the Voximplant cloud, make and receive audio and video calls.

Properties

clientStateStream Stream<VIClientState>
Receive VIClientState each time the state is changed.
no setter
hashCode int
The hash code for this object.
no setterinherited
onIncomingCall VIIncomingCall?
Callback for getting notified about new incoming call.
getter/setter pair
onPushDidExpire VIPushDidExpire?
Triggered when push notification is expired.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(String number, {VICallSettings? settings}) Future<VICall>
Creates a new VICall instance and starts the outgoing call.
conference(String conference, {VICallSettings? settings}) Future<VICall>
Creates a new VICall instance and starts the conference.
connect({required VINode node, bool connectivityCheck = false, List<String>? servers}) Future<void>
Connects to the Voximplant cloud.
disconnect() Future<void>
Closes the connection with the Voximplant cloud.
getClientState() Future<VIClientState>
Returns the current client state
handlePushNotification(Map<String, dynamic> message) Future<void>
Handles incoming push notification.
login(String username, String password) Future<VIAuthResult>
Logs in a user with the given Voximplant username and password.
loginWithAccessToken(String username, String token) Future<VIAuthResult>
Logs in a user with the given Voximplant username and access token.
loginWithOneTimeKey(String username, String hash) Future<VIAuthResult>
Logs in a user with the given Voximplant username and one time key that has been generated before.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerForPushNotifications(String pushToken) Future<void>
Registers for VoIP push notification with the given token.
registerIMPushNotificationsTokenIOS(String imToken) Future<void>
Registers an Apple Push Notifications token.
requestOneTimeLoginKey(String username) Future<String>
Generates one time login key for the given Voximplant username.
tokenRefresh(String username, String token) Future<VILoginTokens>
Performs refresh of access token for the given Voximplant username via a refresh token.
toString() String
A string representation of this object.
inherited
unregisterFromPushNotifications(String pushToken) Future<void>
Unregisters from VoIP push notifications.
unregisterIMPushNotificationsTokenIOS(String imToken) Future<void>
Unregisters an Apple Push Notifications token.

Operators

operator ==(Object other) bool
The equality operator.
inherited