VIConversation class

Interface that may be used to manage a conversation.

Properties

createdTime int
UNIX timestamp (seconds) that specifies the time of the conversation creation.
final
customData Map<String, dynamic>
Custom data, up to 5kb.
getter/setter pair
direct bool
Whether the conversation is direct.
final
hashCode int
The hash code for this object.
no setterinherited
lastSequence int
Sequence of the last event in the conversation.
final
lastUpdateTime int
UNIX timestamp (seconds) that specifies the time when one of VIConversationEvent or VIMessageEvent is the last triggered event in this conversation.
final
participants List<VIConversationParticipant>
List of participants alongside with their permissions.
final
publicJoin bool
Whether the conversation is public.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Current conversation title.
getter/setter pair
uber bool
Whether the conversation is uber.
final
uuid String
An universally unique identifier (UUID) of this conversation.
final

Methods

addParticipants(List<VIConversationParticipant> participants) Future<VIConversationEvent>
Adds new participants to the conversation.
editParticipants(List<VIConversationParticipant> participants) Future<VIConversationEvent>
Edits participants permissions. It is possible only if the current user can manage other participants (VIConversationParticipant.canManageParticipants is true).
markAsRead(int sequence) Future<VIConversationServiceEvent>
Marks the event with the specified sequence as read.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeParticipants(List<VIConversationParticipant> participants) Future<VIConversationEvent>
Removes participants from the conversation.
retransmitEvents(int from, int to) Future<VIRetransmitEvent>
Requests events in the specified sequence range to be sent from the cloud to this client.
retransmitEventsFrom(int from, int count) Future<VIRetransmitEvent>
Requests a number of events starting with the specified sequence to be sent from the cloud to this client.
retransmitEventsTo(int to, int count) Future<VIRetransmitEvent>
Requests a number of events up to the specified sequence to be sent from the cloud to this client.
sendMessage({String? text, List<Map<String, Object>>? payload}) Future<VIMessageEvent>
Sends a message to the conversation.
toString() String
A string representation of this object.
inherited
typing() Future<VIConversationServiceEvent>
Informs the cloud that the user is typing some text.
update() Future<VIConversationEvent>
Sends the conversation changes to the cloud. The sent changes are: title, public join flag and custom data.

Operators

operator ==(Object other) bool
The equality operator.
inherited