VICreateConversation typedef
VICreateConversation =
void Function(VIConversationEvent conversationEvent)
Signature for callbacks reporting that a conversation has been created via VIMessenger.createConversation or analogous methods from other Voximplant SDKs and Messaging API.
Used in VIMessenger.
Triggered only for participants that belong to the conversation.
conversationEvent - VIConversationEvent object with conversation data and service information
Implementation
typedef void VICreateConversation(VIConversationEvent conversationEvent);