onRemoteVideoStreamRemoved property
Triggered when the endpoint removed the video stream from the call.
Implementation
VIRemoteVideoStreamRemoved? onRemoteVideoStreamRemoved;
Triggered when the endpoint removed the video stream from the call.
VIRemoteVideoStreamRemoved? onRemoteVideoStreamRemoved;