VIICETimeout typedef
VIICETimeout =
void Function(VICall call)
Signature for callbacks reporting that the connection has not been established due to a network connection problem between 2 peers.
Used in VICall.
call - VICall instance initiated the event
Implementation
typedef void VIICETimeout(VICall call);