VIMessage class

Interface that represents message within a conversation.

Properties

conversation String
UUID of the conversation this message belongs to.
final
hashCode int
The hash code for this object.
no setterinherited
payload List<Map<String, dynamic>>
List of payload objects associated with the message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence int
Message sequence number in the conversation.
final
text String
Text of this message.
final
uuid String
Universally unique identifier (UUID) of the message.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() Future<VIMessageEvent>
Removes the message from the conversation.
toString() String
A string representation of this object.
inherited
update({String? text, List<Map<String, Object>>? payload}) Future<VIMessageEvent>
Sends text and payload changes to the cloud.

Operators

operator ==(Object other) bool
The equality operator.
inherited