VIMessageEvent class

Interface that represents messenger events related to messages (send, update, remove).

Extends VIMessengerEvent which provides service information (IM user id, action, event type).

Inheritance

Properties

action VIMessengerAction
Action that triggered this event.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
imUserId int?
IM id for the user that initiated the event.
finalinherited
message VIMessage
VIMessage instance with the message information.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence int
Sequence number for this event.
final
timestamp int
UNIX timestamp (seconds) that specifies the time the message event has been triggered.
final
type VIMessengerEventType
Messenger event type.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited