onSendMessage property
Triggered when a new message has been sent to a conversation the current user belongs to.
Implementation
VISendMessage? onSendMessage;
Triggered when a new message has been sent to a conversation the current user belongs to.
VISendMessage? onSendMessage;