VISubscriptionEvent class

Interface that represents the messenger events related to subscriptions.

Extends VIMessengerEvent which provides service information (IM user id, action, event type).

Inheritance

Properties

action VIMessengerAction
Action that triggered this event.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
imUserId int?
IM id for the user that initiated the event.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type VIMessengerEventType
Messenger event type.
finalinherited
users List<int>
The list of the IM user identifiers of the current (un)subscription.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited