displayName property
User's display name which is specified during user creation via the Voximplant control panel or HTTP API.
Display name is available to all users.
Implementation
final String displayName;
User's display name which is specified during user creation via the Voximplant control panel or HTTP API.
Display name is available to all users.
final String displayName;